==> pydantic_schemaorg-0.0.5-py2.py3-none-any.whl: pydantic_schemaorg/Observation.py <==
from pydantic import Field
from typing import Any, Optional, Union, List
from datetime import datetime
from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
from pydantic_schemaorg.DataType import DataType
from pydantic_schemaorg.Intangible import Intangible


class Observation(Intangible):
    """Instances of the class [[Observation]] are used to specify observations about an entity"
     "(which may or may not be an instance of a [[StatisticalPopulation]]), at a particular"
     "time. The principal properties of an [[Observation]] are [[observedNode]], [[measuredProperty]],"
     "[[measuredValue]] (or [[median]], etc.) and [[observationDate]] ([[measuredProperty]]"
     "properties can, but need not always, be W3C RDF Data Cube \"measure properties\", as"
     "in the [lifeExpectancy example](https://www.w3.org/TR/vocab-data-cube/#dsd-example))."
     "See also [[StatisticalPopulation]], and the [data and datasets](/docs/data-and-datasets.html)"
     "overview for more details.

    See https://schema.org/Observation.

    """
    type_: str = Field("Observation", const=True, alias='@type')
    measuredProperty: Any = Field(
        None,
        description="The measuredProperty of an [[Observation]], either a schema.org property, a property"
     "from other RDF-compatible systems e.g. W3C RDF Data Cube, or schema.org extensions"
     "such as [GS1's](https://www.gs1.org/voc/?show=properties).",
    )
    observationDate: Optional[Union[List[datetime], datetime]] = Field(
        None,
        description="The observationDate of an [[Observation]].",
    )
    marginOfError: Optional[Union[List[QuantitativeValue], QuantitativeValue]] = Field(
        None,
        description="A marginOfError for an [[Observation]].",
    )
    observedNode: Any = Field(
        None,
        description="The observedNode of an [[Observation]], often a [[StatisticalPopulation]].",
    )
    measuredValue: Optional[Union[List[DataType], DataType]] = Field(
        None,
        description="The measuredValue of an [[Observation]].",
    )
    

Observation.update_forward_refs()

==> pydantic_schemaorg-0.1.0-py2.py3-none-any.whl: pydantic_schemaorg/Observation.py <==
from pydantic import Field
from pydantic_schemaorg.Property import Property
from typing import List, Optional, Union
from datetime import datetime
from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
from pydantic_schemaorg.StatisticalPopulation import StatisticalPopulation
from pydantic_schemaorg.DataType import DataType
from pydantic_schemaorg.Intangible import Intangible


class Observation(Intangible):
    """Instances of the class [[Observation]] are used to specify observations about an entity"
     "(which may or may not be an instance of a [[StatisticalPopulation]]), at a particular"
     "time. The principal properties of an [[Observation]] are [[observedNode]], [[measuredProperty]],"
     "[[measuredValue]] (or [[median]], etc.) and [[observationDate]] ([[measuredProperty]]"
     "properties can, but need not always, be W3C RDF Data Cube \"measure properties\", as"
     "in the [lifeExpectancy example](https://www.w3.org/TR/vocab-data-cube/#dsd-example))."
     "See also [[StatisticalPopulation]], and the [data and datasets](/docs/data-and-datasets.html)"
     "overview for more details.

    See https://schema.org/Observation.

    """
    type_: str = Field("Observation", const=True, alias='@type')
    measuredProperty: Optional[Union[List[Union[Property, str]], Union[Property, str]]] = Field(
        None,
        description="The measuredProperty of an [[Observation]], either a schema.org property, a property"
     "from other RDF-compatible systems e.g. W3C RDF Data Cube, or schema.org extensions"
     "such as [GS1's](https://www.gs1.org/voc/?show=properties).",
    )
    observationDate: Optional[Union[List[Union[datetime, str]], Union[datetime, str]]] = Field(
        None,
        description="The observationDate of an [[Observation]].",
    )
    marginOfError: Optional[Union[List[Union[QuantitativeValue, str]], Union[QuantitativeValue, str]]] = Field(
        None,
        description="A marginOfError for an [[Observation]].",
    )
    observedNode: Optional[Union[List[Union[StatisticalPopulation, str]], Union[StatisticalPopulation, str]]] = Field(
        None,
        description="The observedNode of an [[Observation]], often a [[StatisticalPopulation]].",
    )
    measuredValue: Optional[Union[List[Union[DataType, str]], Union[DataType, str]]] = Field(
        None,
        description="The measuredValue of an [[Observation]].",
    )
    

Observation.update_forward_refs()
